#!/usr/bin/env python3
"""
DNS Zone Transfer Tool
Parameters:
    - IP: Target DNS server IP
    - port: DNS port (default: 53)
Additional parameters in comments:
    - domain: Target domain name
"""
import dns.query
import dns.zone
import dns.resolver
import argparse
import sys

def try_zone_transfer(ip, domain, port=53):
    try:
        # Try to perform zone transfer
        zone = dns.zone.from_xfr(
            dns.query.xfr(ip, domain, port=port, lifetime=5)
        )
        
        print(f"\nSuccessful zone transfer from {ip}!")
        print(f"Records found in {domain}:\n")
        
        for name, node in zone.nodes.items():
            rdatasets = node.rdatasets
            for rdataset in rdatasets:
                print(f"{name} {rdataset.ttl} {dns.rdatatype.to_text(rdataset.rdtype)}")
                for rdata in rdataset:
                    print(f"-> {rdata}")
                    
    except Exception as e:
        print(f"Zone transfer failed: {str(e)}")
        try:
            # Try to get NS records as fallback
            resolver = dns.resolver.Resolver()
            resolver.nameservers = [ip]
            answers = resolver.resolve(domain, 'NS')
            print("\nNameserver records:")
            for rdata in answers:
                print(f"-> {rdata}")
        except:
            pass

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="DNS Zone Transfer Tool")
    parser.add_argument("ip", help="Target DNS server IP")
    parser.add_argument("domain", help="Target domain name")
    parser.add_argument("--port", type=int, default=53,
                      help="DNS port (default: 53)")
    args = parser.parse_args()
    
    try_zone_transfer(args.ip, args.domain, args.port)
